@@ -3,9 +3,14 @@ skip_if_not(is_pkg_installed(pkg = "broom.helpers"))
 test_that("ard_regression() works", {
   withr::local_options(list(width = 90))
 
+  expect_silent(
+    ard <-
+      lm(AGE ~ ARM, data = cards::ADSL) |>
+      ard_regression(add_estimate_to_reference_rows = TRUE)
+  )
+
   expect_snapshot(
-    lm(AGE ~ ARM, data = cards::ADSL) |>
-      ard_regression(add_estimate_to_reference_rows = TRUE) |>
+    ard |>
       as.data.frame() |>
       dplyr::select(-context, -stat_label, -fmt_fn) |>
       dplyr::mutate(
@@ -13,6 +18,15 @@ test_that("ard_regression() works", {
       )
   )
 
+  expect_equal(
+    ard,
+    ard_regression(
+      x = cards::ADSL,
+      formula = AGE ~ ARM,
+      method = "lm"
+    )
+  )
+
   # checking non-syntactic names
   expect_equal(
     lm(AGE ~ `Treatment Arm`, data = cards::ADSL |> dplyr::rename(`Treatment Arm` = ARM)) |>
