@@ -1,4 +1,4 @@
-skip_if_not(is_pkg_installed(c("broom.helpers", "parameters"), reference_pkg = "cardx"))
+skip_if_not(is_pkg_installed(c("broom.helpers", "parameters")))
 
 test_that("ard_aov() works", {
   expect_error(
